Package: RefManageR
Version: 1.2.0
Title: Straightforward 'BibTeX' and 'BibLaTeX' Bibliography Management
Authors@R: person(c("Mathew", "W."), "McLean", role = c("aut", "cre"),
    email = "mathew.w.mclean@gmail.com")
Author: Mathew W. McLean [aut, cre]
Maintainer: Mathew W. McLean <mathew.w.mclean@gmail.com>
Description: Provides tools for importing and working with bibliographic
    references. It greatly enhances the 'bibentry' class by providing a class
    'BibEntry' which stores 'BibTeX' and 'BibLaTeX' references, supports 'UTF-8'
    encoding, and can be easily searched by any field, by date ranges, and by
    various formats for name lists (author by last names, translator by full names,
    etc.). Entries can be updated, combined, sorted, printed in a number of styles,
    and exported. 'BibTeX' and 'BibLaTeX' '.bib' files can be read into 'R' and
    converted to 'BibEntry' objects. Interfaces to 'NCBI Entrez', 'CrossRef', and
    'Zotero' are provided for importing references and references can be created
    from locally stored 'PDF' files using 'Poppler'. Includes functions for citing
    and generating a bibliography with hyperlinks for documents prepared with
    'RMarkdown' or 'RHTML'.
License: GPL-2 | GPL-3 | BSD_3_clause + file LICENSE
Imports: xml2, jsonlite, utils, plyr, tools, httr, bibtex (>= 0.4.1),
        lubridate (>= 1.5.0), stringr, methods
Suggests: knitr, testthat
Encoding: UTF-8
Depends: R (>= 3.0)
VignetteBuilder: knitr
BugReports: https://github.com/ropensci/RefManageR/issues
URL: https://github.com/ropensci/RefManageR/
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2018-04-25 16:43:52 UTC; root
Repository: CRAN
Date/Publication: 2018-04-25 17:14:14 UTC
Built: R 3.5.1; ; 2018-10-21 22:25:57 UTC; windows
