# Generated by roxygen2: do not edit by hand

S3method("$",BibEntry)
S3method("$<-",BibEntry)
S3method("+",BibEntry)
S3method("[",BibEntry)
S3method("[<-",BibEntry)
S3method("[[",BibEntry)
S3method("[[<-",BibEntry)
S3method("names<-",BibEntry)
S3method(as.data.frame,BibEntry)
S3method(c,BibEntry)
S3method(format,BibEntry)
S3method(head,BibEntry)
S3method(levels,BibEntry)
S3method(merge,BibEntry)
S3method(names,BibEntry)
S3method(open,BibEntry)
S3method(print,BibEntry)
S3method(sort,BibEntry)
S3method(tail,BibEntry)
S3method(toBibtex,BibEntry)
S3method(toRd,BibEntry)
S3method(unlist,BibEntry)
export(AutoCite)
export(BibEntry)
export(BibOptions)
export(Cite)
export(Citep)
export(Citet)
export(GetBibEntryWithDOI)
export(GetDOIs)
export(GetPubMedByID)
export(GetPubMedRelated)
export(LookupPubMedID)
export(NoCite)
export(PrintBibliography)
export(ReadBib)
export(ReadCrossRef)
export(ReadGS)
export(ReadPDFs)
export(ReadPubMed)
export(ReadZotero)
export(RelistBibEntry)
export(SearchBib)
export(TextCite)
export(UpdateFieldName)
export(WriteBib)
export(as.BibEntry)
export(fields)
export(is.BibEntry)
export(toBiblatex)
importFrom(bibtex,do_read_bib)
importFrom(httr,GET)
importFrom(httr,POST)
importFrom(httr,add_headers)
importFrom(httr,content)
importFrom(httr,http_error)
importFrom(httr,modify_url)
importFrom(httr,status_code)
importFrom(httr,stop_for_status)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(lubridate,"%within%")
importFrom(lubridate,int_end)
importFrom(lubridate,int_start)
importFrom(lubridate,interval)
importFrom(lubridate,is.interval)
importFrom(lubridate,month)
importFrom(lubridate,parse_date_time)
importFrom(lubridate,year)
importFrom(methods,hasArg)
importFrom(plyr,llply)
importFrom(plyr,progress_text)
importFrom(stats,setNames)
importFrom(stringr,str_length)
importFrom(stringr,str_sub)
importFrom(stringr,str_trim)
importFrom(tools,Rd2HTML)
importFrom(tools,Rd2latex)
importFrom(tools,Rd2txt)
importFrom(tools,Rd2txt_options)
importFrom(tools,bibstyle)
importFrom(tools,deparseLatex)
importFrom(tools,encoded_text_to_latex)
importFrom(tools,getBibstyle)
importFrom(tools,latexToUtf8)
importFrom(tools,loadPkgRdMacros)
importFrom(tools,parseLatex)
importFrom(tools,toRd)
importFrom(utils,URLdecode)
importFrom(utils,URLencode)
importFrom(utils,as.person)
importFrom(utils,bibentry)
importFrom(utils,browseURL)
importFrom(utils,flush.console)
importFrom(utils,head)
importFrom(utils,person)
importFrom(utils,tail)
importFrom(utils,toBibtex)
importFrom(xml2,read_xml)
importFrom(xml2,xml_attr)
importFrom(xml2,xml_find_all)
importFrom(xml2,xml_text)
